@@ -8,10 +8,11 @@ import incentivedkutils as utils
 import requests
 import xmltodict
 from dateutil import parser
-# import matplotl
 
 
-@utils.timer()
+def main():
+    pass
+
 class Entsoe():
     def __init__(self, token, date_chunksize=30, batch_size=350,max_workers=24):
         self._token = token
@@ -59,7 +60,7 @@ class Entsoe():
             with ThreadPoolExecutor(max_workers=self._max_workers) as executor:
                 indata_list += list(executor.map(Entsoe._get_xml, tasks[batch*batch_size:(batch+1)*batch_size]))
             duration=datetime.utcnow().timestamp()-st
-            if duration < 61:
+            if duration < 61 and batch < len(tasks) // batch_size:
                 time.sleep(61-duration)
         indata_dict = [Entsoe._read_xml(indata[0], indata[1]) for indata in indata_list]
         indata_dict = utils.flatten_list(indata_dict)
