@@ -2,6 +2,7 @@ from concurrent.futures import ThreadPoolExecutor
 
 import requests
 from dateutil import parser
+import incentivedkutils as utils
 
 
 class ICE():
@@ -25,10 +26,12 @@ class ICE():
         product_dict = cls._product_data()
         product = product_dict[product]
         contracts = requests.get(product['contracts_url']).json()
-
         for c in contracts:
             c['contract_date'] = parser.parse(c['endDate'].replace('EDT', 'UTC').replace('EST', 'UTC'))
-        next_contract = min([c['contract_date'] for c in contracts])
+        if product['name'] =='CO2 price':
+            next_contract = min([c['contract_date'] for c in contracts if c['contract_date'].month==12])
+        else:
+            next_contract = min([c['contract_date'] for c in contracts])
         market_id = [c['marketId'] for c in contracts if c['contract_date'] == next_contract][0]
         data_url = f'https://www.theice.com/marketdata/DelayedMarkets.shtml?' \
                    f'getHistoricalChartDataAsJson=&marketId={market_id}&historicalSpan=3'
